# EffiBEM Viewer


[![pypi](https://img.shields.io/pypi/v/effibemviewer.svg)](https://pypi.org/project/effibemviewer/)
[![python](https://img.shields.io/pypi/pyversions/effibemviewer.svg)](https://pypi.org/project/effibemviewer/)
[![Build Status](https://github.com/jmarrec/effibemviewer/actions/workflows/dev.yml/badge.svg)](https://github.com/jmarrec/effibemviewer/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/jmarrec/effibemviewer/branch/main/graphs/badge.svg)](https://codecov.io/github/jmarrec/effibemviewer)


A 3D viewer for OpenStudio building energy models using GLTF and Three.js, that can create a standalone HTML page or be embedded into a Jupyter Notebook.

A Jupyter Notebook [Gltf_notebook.ipynb](https://github.com/jmarrec/effibemviewer/blob/main/Gltf_notebook.ipynb) can serve as a small demonstration of the features.

![Demo in a Jupyter Notebook](https://raw.githubusercontent.com/jmarrec/effibemviewer/refs/heads/main/docs/assets/demo.png)

* Documentation: <https://jmarrec.github.io/effibemviewer>
* GitHub: <https://github.com/jmarrec/effibemviewer>
* PyPI: <https://pypi.org/project/effibemviewer/>


This is free software (MIT License) contributed by [EffiBEM](https://effibem.com).

Leveraging software, [EffiBEM](https://effibem.com) specializes in providing new ways to streamline your workflows and create new tools that work with limited inputs for your specific applications. We also offer support and training services on BEM simulation engines (OpenStudio and EnergyPlus).
